##  Which SAP LeanIX Products Are Needed for ERP Transformation?
  * SAP LeanIX Application Portfolio Management: Enables you to precisely [assess your as-is landscape](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") by creating an application portfolio repository, collecting data with surveys, gaining overviews with predefined reports, and assessing your portfolio with frameworks like TIME, 6R, Pace Layering, and more.
  * SAP LeanIX Architecture and Road Map Planning: Relevant for the second major part of your work with SAP LeanIX to plan the to-be architecture, run transformation initiatives, visualize dependencies in your transformation, and support continuous transformation. It comes with capabilities such as Milestone planning in projects, [Transformation](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet."), and differential report views showing transformation impacts. To learn more about SAP LeanIX Architecture and Road Map Planning, see [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.").
